Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(768)

Unified Diff: ui/base/cursor/cursors_aura.h

Issue 2833163002: Change ui cursor identifiers to an enum class. (Closed)
Patch Set: OK, it can't be explicit for mac. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/base/cursor/cursor_loader_x11.cc ('k') | ui/base/cursor/cursors_aura.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/base/cursor/cursors_aura.h
diff --git a/ui/base/cursor/cursors_aura.h b/ui/base/cursor/cursors_aura.h
index e8eae0ab2deeaae6aa22e9df7bf1695e70886b35..6ce2da62e32b7be905f04b6961f558ca93619c3a 100644
--- a/ui/base/cursor/cursors_aura.h
+++ b/ui/base/cursor/cursors_aura.h
@@ -19,18 +19,18 @@ namespace ui {
const int kAnimatedCursorFrameDelayMs = 25;
// Returns data about |id|, where id is a cursor constant like
// ui::kCursorHelp. The IDR will be placed in |resource_id| and the hotspots
// for the different DPIs will be placed in |hot_1x| and |hot_2x|. Returns
// false if |id| is invalid.
bool UI_BASE_EXPORT GetCursorDataFor(CursorSetType cursor_set_id,
- int id,
+ CursorType id,
float scale_factor,
int* resource_id,
gfx::Point* point);
// Like above, but for animated cursors.
bool UI_BASE_EXPORT GetAnimatedCursorDataFor(CursorSetType cursor_set_id,
- int id,
+ CursorType id,
float scale_factor,
int* resource_id,
gfx::Point* point);
@@ -19,18 +19,18 @@ namespace ui {
const int kAnimatedCursorFrameDelayMs = 25;
// Returns data about |id|, where id is a cursor constant like
-// ui::kCursorHelp. The IDR will be placed in |resource_id| and the hotspots
-// for the different DPIs will be placed in |hot_1x| and |hot_2x|. Returns
-// false if |id| is invalid.
+// ui::CursorType::kHelp. The IDR will be placed in |resource_id| and the
+// hotspots for the different DPIs will be placed in |hot_1x| and |hot_2x|.
+// Returns false if |id| is invalid.
bool UI_BASE_EXPORT GetCursorDataFor(CursorSetType cursor_set_id,
« no previous file with comments | « ui/base/cursor/cursor_loader_x11.cc ('k') | ui/base/cursor/cursors_aura.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698